##  Next Steps
After configuring fact sheet mappings:
  * (Optional) Configure relation mappings to synchronize relations between the systems. For details, see [Relation Mapping Between Jira Service Management and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Configure relation mappings to synchronize relationships and dependencies between Jira Service Management and SAP LeanIX.").
  * Run a manual synchronization to test the configuration. To do this, on the configuration page, choose the three-dot icon > Run Sync.
  * Monitor synchronization results and adjust mappings as needed. On the configuration page, choose Sync Log. You land on the Synchronization Logging page displaying sync logs for the integration.


YesNo
Send
